@@ -2,8 +2,8 @@ from sybil_engine.contract.weth import WETH
 from sybil_engine.data.networks import get_ids_chain
 from sybil_engine.data.tokens import get_tokens_for_chain
 
-from libs.web3_wizzard_lib.core.contract.reactor_fusion_contract import ReactorFusionContract
-from libs.web3_wizzard_lib.core.modules.bank.bank import Bank
+from web3_wizzard_lib.core.contract.reactor_fusion_contract import ReactorFusionContract
+from web3_wizzard_lib.core.modules.bank.bank import Bank
 
 
 class ReactorFusion(Bank):
