@@ -8,13 +8,15 @@ from sybil_engine.utils.retry import retry
 from sybil_engine.utils.utils import ConfigurationException
 from sybil_engine.utils.web3_utils import init_web3
 
-from libs.web3_wizzard_lib.core.modules.bank.basilisk import Basilisk
-from libs.web3_wizzard_lib.core.modules.bank.eralend import Eralend
-from libs.web3_wizzard_lib.core.modules.bank.layerbank import LayerBank
-from libs.web3_wizzard_lib.core.modules.bank.mendi_finance import MendiFinance
-from libs.web3_wizzard_lib.core.modules.bank.aave import Aave
-from libs.web3_wizzard_lib.core.modules.bank.reactorfusion import ReactorFusion
-from libs.web3_wizzard_lib.core.modules.bank.zerolend import ZeroLend
+from web3_wizzard_lib.core.modules.bank.basilisk import Basilisk
+from web3_wizzard_lib.core.modules.bank.cog_bank import Cog
+from web3_wizzard_lib.core.modules.bank.compound_v3 import CompoundV3
+from web3_wizzard_lib.core.modules.bank.eralend import Eralend
+from web3_wizzard_lib.core.modules.bank.layerbank import LayerBank
+from web3_wizzard_lib.core.modules.bank.mendi_finance import MendiFinance
+from web3_wizzard_lib.core.modules.bank.aave import Aave
+from web3_wizzard_lib.core.modules.bank.reactorfusion import ReactorFusion
+from web3_wizzard_lib.core.modules.bank.zerolend import ZeroLend
 
 
 class Banking(Module):
@@ -37,23 +39,31 @@ class Banking(Module):
 
         bank_app = self.get_bank_app(bank_app_name, chain, web3)
 
-        logger.info(f"{bank_app.app_name}")
+        logger.info(f"{bank_app.app_name} | {action}")
 
         self.perform_action(bank_app, action, amount, token, account)
 
     def perform_action(self, bank_app, action, amount, token, account):
-        logger.info(action)
         if action == 'SUPPLY':
             bank_app.supply(account, amount)
         elif action == 'BORROW':
             bank_app.borrow(account, amount)
         elif action == 'REPAY':
-            bank_app.repay_borrow(account, amount)
+            amount = bank_app.get_repay_borrow_amount(account)
+
+            if amount > 0:
+                logger.info(f"Repay {amount} {token} in {bank_app.app_name}")
+                bank_app.repay_borrow(account, amount)
+            else:
+                logger.info(f"{token} borrow balance is 0")
         elif action == 'REDEEM':
             amount = bank_app.get_deposit_amount(account, token)
-            logger.info(f"Redeem {amount} of {token} from {bank_app.app_name}")
 
-            bank_app.redeem(account, amount, token)
+            if amount > 0:
+                logger.info(f"Redeem {amount} of {token} from {bank_app.app_name}")
+                bank_app.redeem(account, amount, token)
+            else:
+                logger.info(f"{token} balance is 0")
         else:
             raise ConfigurationException("Unsupported action")
 
@@ -80,7 +90,9 @@ class Banking(Module):
             MendiFinance,
             LayerBank,
             Aave,
-            ZeroLend
+            ZeroLend,
+            CompoundV3,
+            Cog
         }
 
     def log(self):
