@@ -4,7 +4,7 @@ from sybil_engine.module.module import Module
 from sybil_engine.utils.utils import ConfigurationException
 from sybil_engine.utils.web3_utils import init_web3
 
-from libs.web3_wizzard_lib.core.contract.new_rage_contract import NewRageContract
+from web3_wizzard_lib.core.contract.new_rage_contract import NewRageContract
 
 
 class NewRageModule(Module):
