@@ -2,8 +2,8 @@ from sybil_engine.data.contracts import get_contracts_for_chain
 from sybil_engine.data.networks import get_chain_instance
 from sybil_engine.utils.web3_utils import init_web3
 
-from libs.web3_wizzard_lib.core.contract.l2_telegraph import L2TelegraphMinter
-from libs.web3_wizzard_lib.core.utils.sub_module import SubModule
+from web3_wizzard_lib.core.contract.l2_telegraph import L2TelegraphMinter
+from web3_wizzard_lib.core.utils.sub_module import SubModule
 
 
 class L2Telegraph(SubModule):
