@@ -2,8 +2,8 @@ from sybil_engine.data.networks import get_chain_instance
 from sybil_engine.utils.app_account_utils import AppAccount
 from sybil_engine.utils.web3_utils import init_web3
 
-from libs.web3_wizzard_lib.core.contract.linea_day_3_contract import LineaDay3
-from libs.web3_wizzard_lib.core.utils.sub_module import SubModule
+from web3_wizzard_lib.core.contract.linea_day_3_contract import LineaDay3
+from web3_wizzard_lib.core.utils.sub_module import SubModule
 
 
 class LineaCultureDay3(SubModule):
