@@ -2,8 +2,8 @@ from sybil_engine.data.contracts import get_contracts_for_chain
 from sybil_engine.data.networks import get_chain_instance
 from sybil_engine.utils.web3_utils import init_web3
 
-from libs.web3_wizzard_lib.core.contract.social_scan_contract import SocialScanContract
-from libs.web3_wizzard_lib.core.utils.sub_module import SubModule
+from web3_wizzard_lib.core.contract.social_scan_contract import SocialScanContract
+from web3_wizzard_lib.core.utils.sub_module import SubModule
 
 
 class SocialScan(SubModule):
