@@ -9,8 +9,8 @@ from sybil_engine.utils.scan_utils import find_interacted_contracts
 from sybil_engine.utils.utils import ConfigurationException, randomized_sleeping, RetryException, print_exception_chain
 from sybil_engine.utils.validation_utils import validate_interval
 
-from libs.web3_wizzard_lib.core.modules.nft.nft_submodule import NftSubmodule
-from libs.web3_wizzard_lib.core.utils.sub_module import SubModule
+from web3_wizzard_lib.core.modules.nft.nft_submodule import NftSubmodule
+from web3_wizzard_lib.core.utils.sub_module import SubModule
 
 
 class NFTMinter(RepeatableModule):
