@@ -1,6 +1,6 @@
 from sybil_engine.domain.dex import Dex
 
-from libs.web3_wizzard_lib.core.contract.zebra_contract import ZebraContract
+from web3_wizzard_lib.core.contract.zebra_contract import ZebraContract
 
 
 class Zebra(Dex):
